'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var providers_oauth2 = require('./oauth2.js');
require('./base.js');

const defaultConfig = {
  id: "facebook",
  scope: "email public_profile user_link",
  userProfileFields: "id,name,first_name,last_name,middle_name,name_format,picture,short_name,email"
};
class FacebookAuthProvider extends providers_oauth2.OAuth2Provider {
  constructor(config) {
    super({
      ...defaultConfig,
      ...config
    });
  }
  getSigninUrl({ host }, state) {
    const endpoint = "https://www.facebook.com/v10.0/dialog/oauth";
    const data = {
      client_id: this.config.clientId,
      scope: this.config.scope,
      redirect_uri: this.getCallbackUri(host),
      state
    };
    const url = `${endpoint}?${new URLSearchParams(data)}`;
    return url;
  }
  async getTokens(code, redirectUri) {
    const endpoint = "https://graph.facebook.com/v10.0/oauth/access_token";
    const data = {
      code,
      client_id: this.config.clientId,
      redirect_uri: redirectUri,
      client_secret: this.config.clientSecret
    };
    const res = await fetch(`${endpoint}?${new URLSearchParams(data)}`);
    return await res.json();
  }
  async inspectToken(tokens) {
    const endpoint = "https://graph.facebook.com/debug_token";
    const data = {
      input_token: tokens.access_token,
      access_token: `${this.config.clientId}|${this.config.clientSecret}`
    };
    const res = await fetch(`${endpoint}?${new URLSearchParams(data)}`);
    return await res.json();
  }
  async getUserProfile(tokens) {
    const inspectResult = await this.inspectToken(tokens);
    const endpoint = `https://graph.facebook.com/v10.0/${inspectResult.data.user_id}`;
    const data = {
      access_token: tokens.access_token,
      fields: this.config.userProfileFields
    };
    const res = await fetch(`${endpoint}?${new URLSearchParams(data)}`);
    return await res.json();
  }
}

exports.FacebookAuthProvider = FacebookAuthProvider;
//# sourceMappingURL=facebook.js.map
